# Test Coverage Report: excluded packages and modules

Generated: Thu 2013-05-02 12:21 SGT

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- calendarium.admin
- calendarium.migrations
- calendarium.templatetags.__init__
- calendarium.tests
- calendarium.tests.test_app.__init__
- calendarium.tests.test_app.migrations
- calendarium.urls
- django.contrib.admin
- django.contrib.admindocs
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.messages
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- django.contrib.staticfiles

Back to index.